@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # flake8: noqa
-
+from __future__ import unicode_literals
 
 try:
     from collections import OrderedDict
@@ -8,6 +8,6 @@ except ImportError:
     from ordereddict import OrderedDict
 
 try:
-    from urllib.parse import urlparse, urlunparse
+    from urlparse import urlparse, urlunparse
 except ImportError:
     from urllib.parse import urlparse, urlunparse
