@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+from __future__ import unicode_literals
 
 import difflib
 import inspect
@@ -15,13 +15,13 @@ from flask import make_response as original_flask_make_response
 from flask.helpers import _endpoint_from_view_func
 from flask.signals import got_request_exception
 
-from jsonschema import RefResolver
+from jsonschema import RefResolver, FormatChecker
 
 from werkzeug import cached_property
 from werkzeug.datastructures import Headers
 from werkzeug.exceptions import HTTPException, MethodNotAllowed, NotFound, NotAcceptable, InternalServerError
 from werkzeug.http import HTTP_STATUS_CODES
-from werkzeug.wrappers import Response as ResponseBase
+from werkzeug.wrappers import BaseResponse
 
 from . import apidoc
 from ._compat import OrderedDict
@@ -32,7 +32,6 @@ from .resource import Resource
 from .swagger import Swagger
 from .utils import default_id, camel_to_dash, unpack
 from .representations import output_json
-import collections
 
 RE_RULES = re.compile('(<.*>)')
 
@@ -79,7 +78,9 @@ class Api(object):
     :param dict authorizations: A Swagger Authorizations declaration as dictionary
     :param bool serve_challenge_on_401: Serve basic authentication challenge with 401
         responses (default 'False')
-
+    :param FormatChecker format_checker: A jsonschema.FormatChecker object that is hooked into
+    the Model validator. A default or a custom FormatChecker can be provided (e.g., with custom
+    checkers), otherwise the default action is to not enforce any format validation.
     '''
 
     def __init__(self, app=None, version='1.0', title=None, description=None,
@@ -89,7 +90,7 @@ class Api(object):
             default='default', default_label='Default namespace', validate=None,
             tags=None, prefix='',
             default_mediatype='application/json', decorators=None,
-            catch_all_404s=False, serve_challenge_on_401=False,
+            catch_all_404s=False, serve_challenge_on_401=False, format_checker=None,
             **kwargs):
         self.version = version
         self.title = title or 'API'
@@ -116,6 +117,7 @@ class Api(object):
         self._schema = None
         self.models = {}
         self._refresolver = None
+        self.format_checker = format_checker
         self.namespaces = []
         self.default_namespace = self.namespace(default, default_label,
             endpoint='{0}-declaration'.format(default),
@@ -123,6 +125,7 @@ class Api(object):
             api=self,
             path='/',
         )
+        self.ns_paths = dict()
 
         self.representations = OrderedDict(DEFAULT_REPRESENTATIONS)
         self.urls = {}
@@ -308,7 +311,7 @@ class Api(object):
         @wraps(resource)
         def wrapper(*args, **kwargs):
             resp = resource(*args, **kwargs)
-            if isinstance(resp, ResponseBase):  # There may be a better way to test
+            if isinstance(resp, BaseResponse):
                 return resp
             data, code, headers = unpack(resp)
             return self.make_response(data, code, headers=headers)
@@ -383,19 +386,36 @@ class Api(object):
                 suffix += 1
         return endpoint
 
-    def add_namespace(self, ns):
+    def get_ns_path(self, ns):
+        return self.ns_paths.get(ns)
+
+    def ns_urls(self, ns, urls):
+        path = self.get_ns_path(ns) or ns.path
+        return [path + url for url in urls]
+
+    def add_namespace(self, ns, path=None):
+        '''
+        This method registers resources from namespace for current instance of api.
+        You can use argument path for definition custom prefix url for namespace.
+
+        :param Namespace ns: the namespace
+        :param path: registration prefix of namespace
+        '''
         if ns not in self.namespaces:
             self.namespaces.append(ns)
             if self not in ns.apis:
                 ns.apis.append(self)
+            # Associate ns with prefix-path
+            if path is not None:
+                self.ns_paths[ns] = path
         # Register resources
         for resource, urls, kwargs in ns.resources:
-            self.register_resource(ns, resource, *urls, **kwargs)
+            self.register_resource(ns, resource, *self.ns_urls(ns, urls), **kwargs)
         # Register models
-        for name, definition in list(ns.models.items()):
+        for name, definition in ns.models.items():
             self.models[name] = definition
         # Register error handlers
-        for exception, handler in list(ns.error_handlers.items()):
+        for exception, handler in ns.error_handlers.items():
             self.error_handlers[exception] = handler
 
     def namespace(self, *args, **kwargs):
@@ -600,7 +620,7 @@ class Api(object):
     def _help_on_404(self, message=None):
         rules = dict([(RE_RULES.sub('', rule.rule), rule.rule)
                       for rule in current_app.url_map.iter_rules()])
-        close_matches = difflib.get_close_matches(request.path, list(rules.keys()))
+        close_matches = difflib.get_close_matches(request.path, rules.keys())
         if close_matches:
             # If we already have a message, add punctuation and continue it.
             message = ''.join((
@@ -650,7 +670,7 @@ class Api(object):
         :param **options: See BlueprintSetupState.add_url_rule
         '''
 
-        if isinstance(rule, collections.Callable):
+        if callable(rule):
             rule = rule(blueprint_setup.url_prefix)
         elif blueprint_setup.url_prefix:
             rule = blueprint_setup.url_prefix + rule
@@ -728,7 +748,7 @@ class Api(object):
 
         if self.serve_challenge_on_401:
             realm = current_app.config.get("HTTP_BASIC_AUTH_REALM", "flask-restplus")
-            challenge = "{0} realm=\"{1}\"".format("Basic", realm)
+            challenge = u"{0} realm=\"{1}\"".format("Basic", realm)
 
             response.headers['WWW-Authenticate'] = challenge
         return response
