@@ -8,11 +8,12 @@ from collections import Hashable
 from six import string_types, itervalues, iteritems, iterkeys
 
 from flask import current_app
+from werkzeug.routing import parse_rule
 
 from ._compat import OrderedDict
 
 from . import fields
-from .model import Model
+from .model import Model, ModelBase
 from .reqparse import RequestParser
 from .utils import merge, not_none, not_none_sorted
 
@@ -22,7 +23,7 @@ PATH_TYPES = {
     'int': 'integer',
     'float': 'number',
     'string': 'string',
-    None: 'string',
+    'default': 'string',
 }
 
 
@@ -35,7 +36,6 @@ PY_TYPES = {
 }
 
 RE_URL = re.compile(r'<(?:[^:<>]+:)?([^<>]+)>')
-RE_PARAMS = re.compile(r'<((?:[^:<>]+:)?[^<>]+)>')
 
 DEFAULT_RESPONSE_DESCRIPTION = 'Success'
 DEFAULT_RESPONSE = {'description': DEFAULT_RESPONSE_DESCRIPTION}
@@ -45,7 +45,7 @@ RE_RAISES = re.compile(r'^:raises\s+(?P<name>[\w\d_]+)\s*:\s*(?P<description>.*)
 
 def ref(model):
     '''Return a reference to model in definitions'''
-    name = model.name if isinstance(model, Model) else model
+    name = model.name if isinstance(model, ModelBase) else model
     return {'$ref': '#/definitions/{0}'.format(name)}
 
 
@@ -66,21 +66,22 @@ def extract_path_params(path):
     Extract Flask-style parameters from an URL pattern as Swagger ones.
     '''
     params = OrderedDict()
-    for match in RE_PARAMS.findall(path):
-        descriptor, name = match.split(':') if ':' in match else (None, match)
+    for converter, arguments, variable in parse_rule(path):
+        if not converter:
+            continue
         param = {
-            'name': name,
+            'name': variable,
             'in': 'path',
             'required': True
         }
 
-        if descriptor in PATH_TYPES:
-            param['type'] = PATH_TYPES[descriptor]
-        elif descriptor in current_app.url_map.converters:
+        if converter in PATH_TYPES:
+            param['type'] = PATH_TYPES[converter]
+        elif converter in current_app.url_map.converters:
             param['type'] = 'string'
         else:
-            raise ValueError('Unsupported type converter')
-        params[name] = param
+            raise ValueError('Unsupported type converter: %s' % converter)
+        params[variable] = param
     return params
 
 
@@ -163,7 +164,7 @@ class Swagger(object):
 
         for ns in self.api.namespaces:
             for resource, urls, kwargs in ns.resources:
-                for url in urls:
+                for url in self.api.ns_urls(ns, urls):
                     paths[extract_path(url)] = self.serialize_resource(ns, resource, url, kwargs)
 
         specs = {
@@ -217,7 +218,7 @@ class Swagger(object):
         if doc is False:
             return False
         doc['name'] = resource.__name__
-        params = merge(self.expected_params(doc), doc.get('params', {}))
+        params = merge(self.expected_params(doc), doc.get('params', OrderedDict()))
         params = merge(params, extract_path_params(url))
         doc['params'] = params
         for method in [m.lower() for m in resource.methods or []]:
@@ -238,7 +239,7 @@ class Swagger(object):
         return doc
 
     def expected_params(self, doc):
-        params = {}
+        params = OrderedDict()
         if 'expect' not in doc:
             return params
 
@@ -246,7 +247,7 @@ class Swagger(object):
             if isinstance(expect, RequestParser):
                 parser_params = dict((p['name'], p) for p in expect.__schema__)
                 params.update(parser_params)
-            elif isinstance(expect, Model):
+            elif isinstance(expect, ModelBase):
                 params['payload'] = not_none({
                     'name': 'payload',
                     'required': True,
@@ -428,7 +429,7 @@ class Swagger(object):
                 'items': self.serialize_schema(model),
             }
 
-        elif isinstance(model, Model):
+        elif isinstance(model, ModelBase):
             self.register_model(model)
             return ref(model)
 
@@ -448,14 +449,15 @@ class Swagger(object):
         raise ValueError('Model {0} not registered'.format(model))
 
     def register_model(self, model):
-        name = model.name if isinstance(model, Model) else model
+        name = model.name if isinstance(model, ModelBase) else model
         if name not in self.api.models:
             raise ValueError('Model {0} not registered'.format(name))
         specs = self.api.models[name]
         self._registered_models[name] = specs
-        if isinstance(specs, Model):
+        if isinstance(specs, ModelBase):
             for parent in specs.__parents__:
                 self.register_model(parent)
+        if isinstance(specs, Model):
             for field in itervalues(specs):
                 self.register_field(field)
         return ref(model)
